@@ -15,7 +15,8 @@ ILnumber <- function(input_obj, normalization = "none") { # nolint
   normalization <- check_normalization_key(normalization)
   check_tree(input_obj,
              require_binary = FALSE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
 
   if (inherits(input_obj, "matrix")) {
     il_stat <- ILnumber_ltable_cpp(input_obj)
