@@ -3,7 +3,9 @@ calc_phylogenetic_diversity <- function(phy, t, extinct_tol) {
   if (t == 0 && ape::is.ultrametric(phy, option = 2)) {
     return(sum(phy$edge.length)) # no need to pass to Rcpp
   } else {
-    return(calc_phylodiv_cpp(phy, t, extinct_tol))
+    if (ape::is.rooted(phy)) {
+      return(calc_phylodiv_cpp(phy, t, extinct_tol))
+    }
   }
 }
 
@@ -46,6 +48,10 @@ phylogenetic_diversity <- function(input_obj,
   }
 
   if (inherits(input_obj, "phylo")) {
+    if (!ape::is.rooted(input_obj)) {
+      stop("phylogenetic diversity is not available for unrooted trees")
+    }
+
     if (is.null(extinct_tol)) {
       extinct_tol <- min(input_obj$edge.length) / 100
     }
