@@ -1,7 +1,7 @@
 #' Rquartet index.
 #' @description The rquartet index counts the number of potential fully
 #' balanced rooted subtrees of 4 tips in the tree. The function in treestats
-#' assumes a bifurcating tree. For trees with polytomies, we refer the user to
+#' assumes a bifurcating tree. For trees with polytomies, we use
 #' treebalance::rquartedI, which can also take polytomies into account.
 #' @param phy phylo object or ltable
 #' @param normalization The index can be normalized by the expectation under
@@ -12,6 +12,11 @@
 #' Mathematical Biology, 79(3):1105-1148, 2019. doi: 10.1007/s00285-019-01377-w.
 #' @export
 rquartet <- function(phy, normalization = "none") {
+  check_tree(phy,
+             require_binary = FALSE,
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
+
   normalization <- check_normalization_key(normalization)
 
   if (!inherits(phy, "matrix") && !inherits(phy, "phylo")) {
@@ -22,9 +27,10 @@ rquartet <- function(phy, normalization = "none") {
     answ <- calc_rquartet_ltable_cpp(phy)
   }
   if (inherits(phy, "phylo")) {
-    if (phy$Nnode + 1 != length(phy$tip.label)) {
-  stop("Tree must be binary, for non binary trees use treebalance::rQuartetI")
+    if (!check_binary(phy)) {
+      return(treebalance::rQuartetI(phy))
     }
+
     answ <- calc_rquartet_cpp(as.vector(t(phy$edge)))
   }
 
