@@ -2,6 +2,8 @@ context("all_statistics")
 
 test_that("usage", {
   testthat::skip_on_cran() # these tests take very long
+  testthat::skip_on_ci()
+  testthat::skip_on_covr()
 
   set.seed(42)
   focal_tree <- ape::rphylo(n = 10, birth = 1, death = 0)
@@ -12,9 +14,8 @@ test_that("usage", {
   testthat::expect_equal(length(all_stats), 70)
 
   focal_tree <- ape::rphylo(n = 23175, birth = 1, death = 0)
-  testthat::expect_silent(
-    all_stats <- treestats::calc_all_stats(focal_tree)
-  )
+  all_stats <- treestats::calc_all_stats(focal_tree)
+
   testthat::expect_true(
     is.na(all_stats[names(all_stats) == "laplace_spectrum_a"]))
   testthat::expect_true(
