@@ -44,6 +44,14 @@ test_that("usage", {
   testthat::expect_equal(v_br_int, 1 / 2)
 })
 
+test_that("unrooted", {
+  set.seed(42)
+  focal_tree <- ape::rphylo(n = 100, birth = 1, death = 0)
+  a1 <- treestats::mean_branch_length_ext(focal_tree)
+  a2 <- treestats::mean_branch_length_ext(ape::unroot(focal_tree))
+  testthat::expect_equal(a1, a2)
+})
+
 test_that("wrong_object", {
   testthat::expect_error(
     treestats::var_branch_length(10),
